agentle.mcp.models.embedded\_resource
=====================================

.. automodule:: agentle.mcp.models.embedded_resource

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      Annotations
      BaseModel
      BlobResourceContents
      ConfigDict
      EmbeddedResource
      TextResourceContents
   